==> hwgcod.db_2.0.1.tar.gz: hwgcod.db/man/hwgcod_dbconn.Rd <==
\name{hwgcod_dbconn}

\alias{hwgcod_dbconn}
\alias{hwgcod_dbfile}
\alias{hwgcod_dbschema}
\alias{hwgcod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hwgcod_dbconn()
  hwgcod_dbfile()
  hwgcod_dbschema(file="", show.indices=FALSE)
  hwgcod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hwgcod_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hwgcod_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hwgcod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hwgcod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hwgcod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hwgcod_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hwgcod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hwgcod_dbschema}: none (invisible \code{NULL}).

  \code{hwgcod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hwgcod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hwgcod_dbconn() was created with:
  dbConnect(SQLite(), dbname=hwgcod_dbfile(), cache_size=64000, synchronous=0)

  hwgcod_dbschema()

  hwgcod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hwgcod.db_2.8.0.tar.gz: hwgcod.db/man/hwgcod_dbconn.Rd <==

\name{hwgcod_dbconn}

\alias{hwgcod_dbconn}
\alias{hwgcod_dbfile}
\alias{hwgcod_dbschema}
\alias{hwgcod_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hwgcod_dbconn()
  hwgcod_dbfile()
  hwgcod_dbschema(file="", show.indices=FALSE)
  hwgcod_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hwgcod_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hwgcod_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hwgcod_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hwgcod_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hwgcod_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hwgcod_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hwgcod_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hwgcod_dbschema}: none (invisible \code{NULL}).

  \code{hwgcod_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hwgcod_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hwgcod_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hwgcod_dbfile(), cache_size=64000,
  synchronous=0)

  hwgcod_dbschema()

  hwgcod_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
